# -*- rpm-spec -*-

%define _version 0.600.0
%define _release 5

%define with_rhel6_defaults 0
%define with_selinux 1

%define with_sbin_compat 0

# End local config

%{!?python_sitelib: %define python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}

# This macro is used for the continuous automated builds. It just
# allows an extra fragment based on the timestamp to be appended
# to the release. This distinguishes automated builds, from formal
# Fedora RPM builds
%define _extra_release %{?dist:%{dist}}%{!?dist:%{?extra_release:%{extra_release}}}

%define appname virtinst

%if 0%{?fuduntu} >= 9 || 0%{?rhel} >= 6
%define with_egg 1
%else
%define with_egg 0
%endif


Summary: Python modules and utilities for installing virtual machines
Name: python-%{appname}
Version: %{_version}
Release: %{_release}%{_extra_release}
Source0: http://virt-manager.org/download/sources/%{appname}/%{appname}-%{version}.tar.gz
# Fix installation of translation files
Patch1: %{appname}-fix-po-install.patch
# Handle libvirt getVersion failing (bz 726617)
Patch2: %{appname}-catch-version-errs.patch
# Regenerate outdated man pages
Patch3: %{appname}-regenerate-man-pages.patch
# virt-install: Fix --initrd-inject
Patch4: %{appname}-fix-initrd-inject.patch
# Fix changing disk bus in virt-manager
Patch5: %{appname}-fix-vmm-disk-bus.patch
# Fix remote URL installs as root
Patch6: %{appname}-fix-remote-url.patch

License: GPLv2+
Group: Development/Libraries
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildArch: noarch
Url: http://virt-manager.org
Provides: virt-install
Provides: virt-clone
Provides: virt-image
Provides: virt-convert
Requires: libvirt-python >= 0.2.0
Requires: urlgrabber
Requires: libxml2-python
Requires: python-urlgrabber
Requires: libselinux-python
BuildRequires: gettext
BuildRequires: python

%description
virtinst is a module that helps build and install libvirt based virtual
machines. Currently supports KVM, QEmu and Xen virtual machines. Package
includes several command line utilities, including virt-install (build
and install new VMs) and virt-clone (clone an existing virtual machine).

%prep
%setup -q -n %{appname}-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1

%build
%if %{with_rhel6_defaults}
%define _rhel6_defaults --rhel6defaults
%endif

python setup.py build \
    %{?_rhel6_defaults}


%install
rm -rf $RPM_BUILD_ROOT
python setup.py install -O1 --root=$RPM_BUILD_ROOT
%find_lang %{appname} || echo 0

%clean
rm -rf $RPM_BUILD_ROOT

%files -f %{appname}.lang
%defattr(-,root,root)
%doc README COPYING AUTHORS ChangeLog NEWS doc/image.rng doc/example1.xml
%dir %{python_sitelib}/%{appname}
%dir %{python_sitelib}/virtconv
%{python_sitelib}/%{appname}/*
%{python_sitelib}/virtconv/*
%if %{with_egg}
%{python_sitelib}/%{appname}-*.egg-info
%endif
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_bindir}/virt-install
%{_bindir}/virt-clone
%{_bindir}/virt-image
%{_bindir}/virt-convert

%changelog
* Tue Sep 04 2012 Andrew Wyatt <andrew@fuduntu.org> - %{_version}-
- Built for Fuduntu

* Tue Sep 27 2011 Cole Robinson <crobinso@redhat.com> - 0.600.0-5
- virt-install: Fix --initrd-inject
- Fix changing disk bus in virt-manager
- Fix remote URL installs as root

* Tue Aug 02 2011 Cole Robinson <crobinso@redhat.com> - 0.600.0-4
- Bump to fix build number

* Tue Aug 02 2011 Cole Robinson <crobinso@redhat.com> - 0.600.0-3
- Regenerate outdated man pages

* Mon Aug 01 2011 Cole Robinson <crobinso@redhat.com> - 0.600.0-2
- Fix installation of translation files
- Handle libvirt getVersion failing (bz 726617)

* Tue Jul 26 2011 Cole Robinson <crobinso@redhat.com> - 0.600.0-1.fc16
- Rebased to version 0.600.0
- virt-install: Various improvements to enable LXC/container guests:
- New --filesystem option for <filesystem> devices
- New --init option for container <init> path
- New --container option (similar to --paravirt or --hvm)
- virt-install: Make --location  remotely (with latest libvirt)
- virt-install: New --smartcard option for <smartcard> devices
- (Marc-André Lureau)
- virt-install: New --numatune option for building guest <numatune> XML
- virt-install: option to set --disk error_policy=
- virt-install: option to set --disk serial=

* Thu Apr 07 2011 Cole Robinson <crobinso@redhat.com> - 0.500.6-2.fc16
- Don't parse spice channel XML as a <channel> device
- Properly advertise spicevmc options for use by virt-manager

* Mon Mar 28 2011 Cole Robinson <crobinso@redhat.com> - 0.500.6-1.fc16
- Rebased to version 0.500.6
- virt-install: --graphics spice now enables spicevmc and qxl
- virt-install: New --disk parameter io=native|threads

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.500.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Feb  2 2011 Cole Robinson <crobinso@redhat.com> - 0.500.5-1
- Update to version 0.500.5
- New virt-install --cpu option for configuring CPU model/features
- virt-install --vcpus option can not specify topology and maxvcpus
- New virt-install --graphics option to unify --vnc, --sdl, spice config
- New virt-install --print-xml option to skip install and print XML

* Wed Aug 25 2010 Cole Robinson <crobinso@redhat.com> - 0.500.4-1.fc14
- New virt-install --console option for specifying virtio console device
- New virt-install --channel option for specifying guest communication channel
- New virt-install --boot option. Allows setting post-install boot
  order, direct kernel/initrd boot, and enabling boot device menu.
- New virt-install --initrd-inject option, which enables installation
  using a _local_ kickstart file (Colin Walters)

* Thu Jul 22 2010 David Malcolm <dmalcolm@redhat.com> - 0.500.3-5
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Wed Jul 15 2010 Cole Robinson <crobinso@redhat.com> - 0.500.3-4.fc14
- Drop default CPU config, fix some 64bit installs (bz 611584)

* Wed Jul 14 2010 Cole Robinson <crobinso@redhat.com> - 0.500.3-3.fc14
- If host is 64bit, make sure VM always sees 64bit CPU (bz 611584)

* Wed Jul 07 2010 Cole Robinson <crobinso@redhat.com> - 0.500.3-2.fc14
- Keep windows CDROM attached for second install stage
- Fix pool source listing in virt-manager

* Wed Mar 24 2010 Cole Robinson <crobinso@redhat.com> - 0.500.2-3.fc14
- Update to version 0.500.3
- virt-install: New --watchdog option: configure a virtual watchdog device
- virt-install: New --soundhw option: More flexible sound configuration
                deprecates --sound, though back compat is maintained
- virt-install: New --security option: configure VM security driver settings
- virt-install: New --description option: set a human readable description
- Better OS defaults: Use <video> VGA and <sound> AC97 if supported

* Mon Mar 22 2010 Cole Robinson <crobinso@redhat.com> - 0.500.2-3.fc14
- Enable x2apic for new KVM guests

* Sun Mar 21 2010 Cole Robinson <crobinso@redhat.com> - 0.500.2-2.fc14
- Improve clone progress reporting (bz 550870)
- virt-install: Fix windows installs

* Mon Feb  8 2010 Cole Robinson <crobinso@redhat.com> - 0.500.2-1.fc13
- Update to version 0.500.2
- virt-install --autostart option for setting domain autostart flag
- virt-install --host-device now supports values via lsusb and lspci

* Wed Dec 09 2009 Cole Robinson <crobinso@redhat.com> - 0.500.1-2.fc13
- Fix interface API detection for libvirt < 0.7.4

* Thu Dec  3 2009 Cole Robinson <crobinso@redhat.com> - 0.500.1-1.fc13
- Update to version 0.500.1
- virt-install now attempts --os-variant detection by default.
- New --disk option 'format', for creating image formats like qcow2 or vmdk
- Many improvements and bugfixes

* Mon Oct 05 2009 Cole Robinson <crobinso@redhat.com> - 0.500.0-5.fc12
- Update translations (bz 493795)

* Thu Sep 24 2009 Cole Robinson <crobinso@redhat.com> - 0.500.0-4.fc12
- Don't use usermode net for non-root qemu:///system via virt-install
- Fix cdrom installs where the iso is a storage volume (bz 524109)
- Fix path permissions for kernel/initrd download location (bz 523960)

* Wed Sep 16 2009 Cole Robinson <crobinso@redhat.com> - 0.500.0-3.fc12
- Don't generate bogus disk driver XML.
- Add '--disk format=' for specifying format (qcow2, ...) when provisioning
- Add Fedora12 to os dictionary

* Sun Sep 13 2009 Cole Robinson <crobinso@redhat.com> - 0.500.0-2.fc12
- Don't erroneously set limit for amount of virtio devices (bz 499654)
- Don't use virtio for cdrom devices (bz 517151)
- Auto detect keymapping (bz 487735)

* Tue Jul 28 2009 Cole Robinson <crobinso@redhat.com> - 0.500.0-1.fc12
- Update to version 0.500.0
- New virt-install device options --serial, --parallel, and --video
- Allow various auth types for libvirt connections (PolicyKit, SASL, ...)
- New virt-clone option --auto-clone: generates all needed input.
- Specify network device model via virt-install --network (Guido Gunther)

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.400.3-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed May 06 2009 Cole Robinson <crobinso@redhat.com> - 0.400.3-8.fc12
- Fix PCI assignment (bz 499267)

* Tue Apr 21 2009 Cole Robinson <crobinso@redhat.com> - 0.400.3-7.fc11
- Only warn if selinux labeling appears to be wrong (bz 496340)

* Tue Apr 14 2009 Cole Robinson <crobinso@redhat.com> - 0.400.3-6.fc11
- More translation updates

* Thu Apr 9 2009 Cole Robinson <crobinso@redhat.com> - 0.400.3-5.fc11
- Don't set a keymap if user doesn't specify one (bz 487737)
- Fix adding floppy devices (bz 493408)
- Updated translations (bz 493944, bz 494358)

* Fri Apr  3 2009 Daniel P. Berrange <berrange@redhat.com> - 0.400.3-4.fc11
- Attempt to fix SELinux labelling on CDROM ISOs used for installation

* Fri Apr  3 2009 Daniel P. Berrange <berrange@redhat.com> - 0.400.3-3.fc11
- Set SELinux context on $HOME/.virtinst to make kernel/initrd boot work (rhbz #491052)

* Mon Mar 23 2009 Cole Robinson <crobinso@redhat.com> - 0.400.3-2.fc11
- Add spanish translation (bz 480816)
- Fix calls to libvirt host device detach/reset
- Fix virt-image with create-on-the-fly disks

* Tue Mar 10 2009 Cole Robinson <crobinso@redhat.com> - 0.400.3-1.fc11
- Update to bugfix release 0.400.3
- Fix virt-install --os-type windows installs
- Fix URL installs to not wipe out --os-variant value

* Thu Mar  5 2009 Cole Robinson <crobinso@redhat.com> - 0.400.2-3.fc11
- Fix virt-install --file option (bz 488731)

* Wed Mar  4 2009 Cole Robinson <crobinso@redhat.com> - 0.400.2-2.fc11
- Update polish translation (bz 310781)

* Tue Mar  3 2009 Cole Robinson <crobinso@redhat.com> - 0.400.2-1.fc11
- Update to version 0.400.2
- virt-install --import option for creating a guest from an existing disk
- virt-install --host-device option for host device passthrough
- virt-clone --original-xml for cloning from an xml file
- virt-install --nonetworks option.

* Fri Feb 27 2009 Daniel P. Berrange <berrange@redhat.com> - 0.400.1-3.fc11
- Add Fedora 11 OS type with USB tablet (rhbz #487028)

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.400.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Jan 26 2009 Cole Robinson <crobinso@redhat.com> - 0.400.1-1.fc11
- Update to 0.400.1
- virt-convert virt-image -> vmx support
- virt-image checksum support
- Improved URL fetching support (Debian Xen, Ubuntu kernel + boot.iso)

* Thu Dec 04 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 0.400.0-7
- Rebuild for Python 2.6

* Tue Dec  2 2008 Cole Robinson <crobinso@redhat.com> - 0.400.0-6.fc11
- Fix printing translated help messages
- Allow using virtio to pxe boot

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 0.400.0-5
- Rebuild for Python 2.6

* Mon Oct 27 2008 Cole Robinson <crobinso@redhat.com> - 0.400.0-4.fc10
- Updated translations (bz 467810)
- Specific os entry for XP 64 (bz 467851)
- Disk pool 'dos' format fix

* Mon Oct 20 2008 Cole Robinson <crobinso@redhat.com> - 0.400.0-3.fc10
- Fix missing variable error (bz 467228)

* Tue Oct 14 2008 Cole Robinson <crobinso@redhat.com> - 0.400.0-2.fc10
- Updated polish translation (bz 310781)
- Fix error accessing os dictionary in virt-convert
- Log tracebacks from cli apps
- Better default connection detection for qemu/kvm
- Set up virtio for f9 guests (bz 462404)
- Don't report option collision if using --bridge
- Update storage pool when looking up volume (bz 465551)

* Wed Sep 10 2008 Cole Robinson <crobinso@redhat.com> - 0.400.0-1.fc10
- Add virt-convert tool
- Add virt-pack tool
- virt-install --disk option for using/provisioning libvirt storage
- virt-install remote installation support
- virt-install --sound option to add soundcard emulation

* Wed Jun  4 2008 Daniel P. Berrange <berrange@redhat.com> - 0.300.3-7.fc10
- Fix fetching of HVM kernels (rhbz #450032)

* Fri May  9 2008 Daniel P. Berrange <berrange@redhat.com> - 0.300.3-6.fc10
- Use /var/lib/libvirt/boot for kernel/initrd images (rhbz #445854)

* Tue Apr  8 2008 Daniel P. Berrange <berrange@redhat.com> - 0.300.3-5.fc9
- Added Serbian translation

* Thu Apr  3 2008 Daniel P. Berrange <berrange@redhat.com> - 0.300.3-4.fc9
- Added italian translation

* Tue Apr 1 2008 Cole Robinson <crobinso@redhat.com> - 0.300.3-3.fc9
- Revert unintentionally committed spec change.

* Thu Mar 27 2008 Cole Robinson <crobinso@redhat.com> - 0.300.3-2.fc9
- Keep qemu cdrom device after first stage of install. (rhbz #244802)
- Fix default guest arch regression from virt-install
- Pass extra args to a fullvirt guest from virt-install
- Update polish translation

* Mon Mar 10 2008 Daniel P. Berrange <berrange@redhat.com> - 0.300.3-1.fc9
- Update to 0.300.3 release

* Thu Jan 31 2008 Daniel P. Berrange <berrange@redhat.com> - 0.300.2-3.fc9
- Disable virt-viewer dep to allow non-X installs (rhbz #387971)

* Thu Jan 10 2008 Daniel P. Berrange <berrange@redhat.com> - 0.300.2-2.fc9
- Added dep on libxml2-python and python-urlgrabber

* Thu Jan 10 2008 Daniel P. Berrange <berrange@redhat.com> - 0.300.2-1.fc9
- Update to 0.300.2 release

* Thu Oct 11 2007 Daniel P. Berrange <berrange@redhat.com> - 0.300.1-3.fc8
- Fix missing file exception check with NFS installs (rhbz #325591)

* Thu Oct  4 2007 Daniel P. Berrange <berrange@redhat.com> - 0.300.1-2.fc8
- Remove USB tablet for all except Windows (rhbz #302951)

* Tue Sep 25 2007 Daniel P. Berrange <berrange@redhat.com> - 0.300.1-1.fc8
- Update to 0.300.1 release
- Added PXE support

* Wed Sep 19 2007 Daniel P. Berrange <berrange@redhat.com> - 0.300.0-4.fc8
- Fix post install CDROM config for KVM guests

* Tue Sep 11 2007 Daniel P. Berrange <berrange@redhat.com> - 0.300.0-3.fc8
- Fixed default architecture. Again.

* Tue Sep 11 2007 Daniel P. Berrange <berrange@redhat.com> - 0.300.0-2.fc8
- Fixed detection of Fedora 8 distro trees (rhbz #273781)

* Wed Aug 29 2007 Daniel P. Berrange <berrange@redhat.com> - 0.300.0-1.fc8
- Updated to 0.300.0
- Added virt-image tool
- Switched to calling virsh console and virt-viewer
- Improved user input validation

* Fri Aug 24 2007 Daniel P. Berrange <berrange@redhat.com> - 0.200.0-3.fc8
- Remove ExludeArch since libvirt is now available everywhere

* Thu Jul 26 2007 Daniel P. Berrange <berrange@redhat.com> - 0.200.0-2.fc8
- Fixed default architecture

* Tue Jul 18 2007 Daniel P. Berrange <berrange@redhat.com> - 0.200.0-1.fc8
- Updated to 0.200.0
- Added virt-clone tool
- Added manual pages

* Tue May  1 2007 Daniel P. Berrange <berrange@redhat.com> - 0.103.0-3.fc7
- Fixed module import when using --accelerate
- Fixed detection of RHEL5 client distro
- Fixed default 'network's selection & default URI choice to
  not be Xen specific
- Fixed features XML when using initrd for fullvirt

* Tue Apr 17 2007 Mark McLoughlin <markmc@redhat.com> - 0.103.0-2.fc7
- Fix urlgrabber import error

* Mon Apr 16 2007 Daniel P. Berrange <berrange@redhat.com> - 0.103.0-1.fc7
- Updated to 0.103.0 release
- More validation of UUIDs
- Automatically reboot Windows guests with CDROM still attached
- Allow '-'  in guest names
- Adjust way distro detection is done

* Tue Mar 20 2007 Daniel P. Berrange <berrange@redhat.com> - 0.102.0-1.fc7
- Updated to 0.102.0 release

* Thu Mar  8 2007 Daniel P. Berrange <berrange@redhat.com> - 0.101.0-4.fc7
- Fixed install of paravirt Xen guests

* Fri Mar  2 2007 Daniel P. Berrange <berrange@redhat.com> - 0.101.0-3.fc7
- Fixed restart of guests after install completes

* Tue Feb 20 2007 Daniel P. Berrange <berrange@redhat.com> - 0.101.0-2.fc7
- Remove obsolete patches

* Tue Feb 20 2007 Daniel P. Berrange <berrange@redhat.com> - 0.101.0-1.fc7
- Updated to 0.101.0 to enable QEMU support

* Thu Jan 25 2007 Daniel P. Berrange <berrange@redhat.com> - 0.100.0-3.fc7
- Make back-compat with old APIs for Cobbler sanity

* Thu Jan 25 2007 Daniel P. Berrange <berrange@redhat.com> - 0.100.0-2.fc7
- Fix errors with NFS mount based installs

* Mon Jan 22 2007 Daniel P. Berrange <berrange@redhat.com> - 0.100.0-1.fc7
- Updated to 0.100.0 which now uses libvirt inactive domain support
  needed to operate correctly against xen 3.0.4

* Tue Dec 18 2006 Daniel P. Berrange <berrange@redhat.com> - 0.98.0-3.fc7
- don't traceback on invalid memory param (gcosta, #219270)
- let the console come back quicker to help with HVM installs (#212024)

* Thu Dec  7 2006 Jeremy Katz <katzj@redhat.com> - 0.98.0-2
- rebuild for python 2.5

* Thu Nov 30 2006 Jeremy Katz <katzj@redhat.com> - 0.98.0-1
- add support for creating nonsparse disk images (#217764)
- remove xeninst compat bits

* Mon Nov 20 2006 Jeremy Katz <katzj@redhat.com> - 0.97.0-1
- handle multiple nics/disks on virt-install command line (#215726)
- buildrequire python

* Wed Oct 18 2006 Jeremy Katz <katzj@redhat.com> - 0.96.0-1
- improve check for if a machine is hvm capable to catch when support isn't
  allowed by the bios (#211276)
- cleanup after nfs mount failure on pv install (#206196)
- support for setting vcpus (#210516)

* Thu Oct 12 2006 Jeremy Katz <katzj@redhat.com> - 0.95.0-1
- support for blktap (danpb)
- name change

* Tue Oct  3 2006 Jeremy Katz <katzj@redhat.com> - 0.94.0-1
- Fix using block device as backing (#209138)
- Fix error handling for invalid install locations (danpb)
- Write out vcpu config (danpb)

* Wed Sep 20 2006 Jeremy Katz <katzj@redhat.com> - 0.93.0-1
- Fix hvm network xm config (danpb)
- Enable PAE with pae hvm hosts (danpb)
- Fix hvm block backed cds (danpb)
- Fix handling of block devs backed by vbds (danpb)
- Ensure we're on a xen kernel (#205889)
- Default to vncunused

* Wed Sep  6 2006 Jeremy Katz <katzj@redhat.com> - 0.92.0-2
- add patch to fix memory parsing in interactive mode
- fix deps

* Wed Aug 30 2006 Jeremy Katz <katzj@redhat.com> - 0.92.0-1
- Fix silly loop when asking about graphics support (misa)
- Fix passing macaddr
- Add support so that we reboot into the guest after installation finishes 

* Tue Aug 29 2006 Jeremy Katz <katzj@redhat.com> - 0.91.0-1
- add support for paravirt guests with framebuffer. 

* Mon Aug 21 2006 Jeremy Katz <katzj@redhat.com> - 0.90.1-1
- fix tab/space whitespace inconsistency

* Wed Aug 16 2006 Jeremy Katz <katzj@redhat.com> - 0.90.0-2
- set ExcludeArch so that it doesn't get pulled into all trees

* Wed Aug 16 2006 Jeremy Katz <katzj@redhat.com> - 0.90.0-1
- update to version with fixed HVM domain creation

* Wed Aug 16 2006 Jeremy Katz <katzj@redhat.com> - 0.9-2
- add some missing requires

* Tue Aug 15 2006 Jeremy Katz <katzj@redhat.com> - 0.9-1
- Initial build

